@@ -8,13 +8,13 @@
 #  modification, are permitted provided that the following conditions are met:
 #
 #   * Redistributions of source code must retain the above copyright notice,
-#     this list of conditions and the following disclaimer.
+#	 this list of conditions and the following disclaimer.
 #   * Redistributions in binary form must reproduce the above copyright notice,
-#     this list of conditions and the following disclaimer in the documentation
-#     and/or other materials provided with the distribution.
+#	 this list of conditions and the following disclaimer in the documentation
+#	 and/or other materials provided with the distribution.
 #   * Neither the name of SWITCH nor the names of its contributors may be
-#     used to endorse or promote products derived from this software without
-#     specific prior written permission.
+#	 used to endorse or promote products derived from this software without
+#	 specific prior written permission.
 #
 #  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 #  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -28,11 +28,11 @@
 #  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 #  POSSIBILITY OF SUCH DAMAGE.
 #
-#  $Author: phaag $
+#  $Author: haag $
 #
-#  $Id: install.pl 24 2007-11-21 09:12:03Z phaag $
+#  $Id: install.pl 67 2010-09-09 05:56:05Z haag $
 #
-#  $LastChangedRevision: 24 $
+#  $LastChangedRevision: 67 $
 
 require 5.6.0;
 
@@ -49,10 +49,11 @@ use Nfsources;
 # from installer-items - helper modules
 use CopyRecursive;
 use File::Copy;
+use File::Path;
 use RRDconvertv1;
 
-my $VERSION = '$Id: install.pl 24 2007-11-21 09:12:03Z phaag $';
-my $nfsen_version = "1.3.2";
+my $VERSION = '$Id: install.pl 67 2010-09-09 05:56:05Z haag $';
+my $nfsen_version = "1.3.5";
 
 my @ProfileTag = ( 
 	"# \n",
@@ -60,12 +61,11 @@ my @ProfileTag = (
 	"# \n",
 );
 
-my $instdir = $ENV{'INSTDIR'};
-
 my @RequiredDirs = ( 'PREFIX', 'BINDIR', 'LIBEXECDIR', 'CONFDIR', 'DOCDIR', 
-					 'VARDIR', 'PROFILESTATDIR', 'PROFILEDATADIR', 
+					 'VARDIR', 'PIDDIR', 'FILTERDIR', 'PROFILESTATDIR', 'PROFILEDATADIR', 
 					 'BACKEND_PLUGINDIR', 'FRONTEND_PLUGINDIR', 'HTMLDIR' );
 #
+
 sub FindCommand {
 	my $command = shift;
 
@@ -89,11 +89,11 @@ sub GetPerl {
 	my $ans;
 	$whichperl = FindCommand("perl");
 	if ( defined $whichperl ) {
-		print "Perl to use: [$whichperl]\n";
-#		chomp($ans = <STDIN>);
-#		if ( length $ans ) {
-#			$whichperl = $ans;
-#		}
+		print "Perl to use: [$whichperl] ";
+		chomp($ans = <STDIN>);
+		if ( length $ans ) {
+			$whichperl = $ans;
+		}
 	} else {
 		print "No Perl found in your PATH. Please specify where to find perl [] ";
 		chomp($whichperl = <STDIN>);
@@ -118,10 +118,9 @@ sub GetPerl {
 sub CopyDir {
 	my $orig = shift;
 	my $dest = shift;
-	$dest = $instdir.$dest;
 
 	my $DIR;
-	mkdir $dest unless -d $dest;
+	mkpath($dest, 1, 0755) unless -d $dest;
 	opendir($DIR, $orig) || die "can't open dir $orig: $!\n";
 	while ( my $direntry = readdir $DIR ) {
 		next if $direntry eq '.';
@@ -166,7 +165,7 @@ sub VerifyUser {
 #	# Check the members list
 #	foreach my $member ( split /\s+/, $group_members ) {
 #		if ( $member eq $user ) {
-#			# user found
+			# user found
 			return $uid;
 #		}
 #	}
@@ -195,11 +194,26 @@ sub VerifyConfig {
 	}
 
 	die "Missing PREFIX directory of nfdump tools!\n" unless defined $NfConf::PREFIX;
-	die "Configured PREFIX directory '$instdir$NfConf::PREFIX' not found!\n" unless -d  $instdir.$NfConf::PREFIX;
+	die "Configured PREFIX directory '$NfConf::PREFIX' not found!\n" unless -d  $NfConf::PREFIX;
 	foreach my $binary ( 'nfcapd', 'nfdump', 'nfprofile' ) {
 		die "nfdump tools installation error: '$binary' not found in '$NfConf::PREFIX'" unless -f "$NfConf::PREFIX/$binary";
 	}
 
+	my @out = `$NfConf::PREFIX/nfdump -V`;
+	if ( scalar @out != 2 ) {
+		die "Error getting nfdump version";
+	}
+	chomp $out[0];
+	my ($major, $minor) = $out[0] =~ /Version:\s(\d)\.(\d)\s/;
+	if ( defined $major && defined $minor) {
+		if ( $major >= 1 && $minor >= 6 ) {
+			print "Found $out[0]\n";
+		} else {
+			print "out[0]\n";
+			die "Nfdump version not compatible with current NfSen version.\n";
+		}
+	} 
+
 	my $www_gid = getgrnam($NfConf::WWWGROUP) || 
 		die "WWW group '$NfConf::WWWGROUP' not found on this system\n";
 
@@ -212,33 +226,8 @@ sub VerifyConfig {
 		die "Selected subdir hierarchy %NfConf::SUBDIRLAYOUT out of range\n";
 	}
 
-	my %_seen;
-	foreach my $source ( keys %NfConf::sources ) {
-		my $len = length($source);
-		if ( $len < 1 || $len > 19 ) {
-			die "Error Ident: '$source': Source identifiers must be between 1 and 19 chars long!\n";
-		}
-		if ( $source =~ /[^a-z0-9_\-]+/i ) {
-			die "Error Ident: '$source': Source identifiers must contain only characters [a-zA-Z0-9_-] !\n";
-		}
-		my $port = $NfConf::sources{$source}{'port'};
-		if ( $port > 0 && exists $_seen{$port} ) {
-			die "Error Ident: '$source': Port $port already configured for source $_seen{$port}!\n";
-		} else {
-			$_seen{$port} = $source;
-		}
-		# 
-		my $type = $NfConf::sources{$source}{'type'};
-		if ( defined $type ) {
-			$type = lc $type;
-			my $collector = $NfSenRC::CollectorMap{$type};
-
-			if ( !defined $collector ) {
-				die "Source '$source': unknown collector for type '$type'";
-			} elsif ( ! -f "$NfConf::PREFIX/$collector" ) {
-				die "Source '$source': missing collector '$collector' for type '$type'";
-			}
-		}
+	if ( !Nfsources::ValidateSources() ) {
+		die "Fix errors for %source in your config file and retry!\n";
 	}
 
 	if ( !defined $NfConf::low_water ) {
@@ -286,23 +275,23 @@ sub PatchVars {
 sub PatchAllScripts {
 
 	my %GlobList = ( 
-		"bin/*"		=> 	"$instdir$NfConf::BINDIR",
-		"libexec/*"	=>	"$instdir$NfConf::LIBEXECDIR"
+		"bin/*"		=> 	"$NfConf::INSTPREFIX$NfConf::BINDIR",
+		"libexec/*"	=>	"$NfConf::INSTPREFIX$NfConf::LIBEXECDIR"
 	);
 
 	foreach my $glob_list ( keys %GlobList ) {
 		my $dir 	= $GlobList{$glob_list};
-    	my @Scripts	= glob($glob_list);
+		my @Scripts	= glob($glob_list);
 		print "In directory: $dir ...\n";
-    	foreach my $script (@Scripts) {
-        	$script =~ s#^.+/##;
-        	if ( -f "$dir/$script" ) {
-            	print "Update script: $script\n";
+		foreach my $script (@Scripts) {
+			$script =~ s#^.+/##;
+			if ( -f "$dir/$script" ) {
+				print "Update script: $script\n";
 				PatchVars("$dir/$script");
-        	} else {
-            	print "ERROR: Failed to update script: '$script'. Installation incomplete!\n";
-        	}
-    	}
+			} else {
+				print "ERROR: Failed to update script: '$script'. Installation incomplete!\n";
+			}
+		}
 	}
 
 	print "\n";
@@ -319,8 +308,8 @@ sub RenameFiles {
 			foreach my $profile ( @AllProfiles ) {
 				foreach my $type (  'flows', 'packets', 'traffic' ) {
 					foreach my $periode (  'day', 'week', 'month',  'year' ) {
-						my $oldfile = "$NfConf::PROFILESTATDIR/$profilegroup/$profile/${type}-${periode}.gif";
-						my $newfile = "$NfConf::PROFILESTATDIR/$profilegroup/$profile/${type}-${periode}.png";
+						my $oldfile = "$NfConf::INSTPREFIX$NfConf::PROFILESTATDIR/$profilegroup/$profile/${type}-${periode}.gif";
+						my $newfile = "$NfConf::INSTPREFIX$NfConf::PROFILESTATDIR/$profilegroup/$profile/${type}-${periode}.png";
 						if ( -f $oldfile ) {
 							rename $oldfile, $newfile;
 						}
@@ -337,17 +326,17 @@ sub SetupHTML {
 	my ( $nfsen_uid, $www_gid ) = @_;
 
 	print "Setup php and html files.\n";
-	mkdir "$instdir$NfConf::HTMLDIR" unless -d "$instdir$NfConf::HTMLDIR";
-	die "Could not create HTMl directory '$instdir$NfConf::HTMLDIR': $!\n"  unless -d $instdir.$NfConf::HTMLDIR;
+	mkpath("$NfConf::INSTPREFIX$NfConf::HTMLDIR", 1, 0755) unless -d "$NfConf::INSTPREFIX$NfConf::HTMLDIR";
+	die "Could not create HTMl directory '$NfConf::INSTPREFIX$NfConf::HTMLDIR': $!\n"  unless -d "$NfConf::INSTPREFIX$NfConf::HTMLDIR";
 
 	$CopyRecursive::CopyLink = 1;
 	$CopyRecursive::MODE 	 = 0644;
 	$CopyRecursive::UID 	 = 0;
 	$CopyRecursive::GID 	 = $www_gid;
-	CopyRecursive::dircopy("html", "$instdir$NfConf::HTMLDIR");
-	open CONF, ">$instdir$NfConf::HTMLDIR/conf.php" || die "Can't open conf.php for writing: $!\n";
+	CopyRecursive::dircopy("html", "$NfConf::INSTPREFIX$NfConf::HTMLDIR");
+	open CONF, ">$NfConf::INSTPREFIX$NfConf::HTMLDIR/conf.php" || die "Can't open conf.php for writing: $!\n";
 	print CONF "<?php\n";
-	print CONF "/* This file was automatically created by the NfSen install.pl script */\n\n";
+	print CONF "/* This file was automatically created by the NfSen $nfsen_version install.pl script */\n\n";
 	print CONF "\$COMMSOCKET = \"$NfConf::COMMSOCKET\";\n";
 	print CONF "\n\$DEBUG=0;\n";
 	print CONF "\n?>\n";
@@ -365,24 +354,23 @@ sub SetupEnv {
 	umask 0002;
 	print "\nSetup diretories:\n";
 	my @dirs = (
-		"$NfConf::VARDIR",
-		"$NfConf::PIDDIR",
-		"$NfConf::VARDIR/tmp",
-		"$NfConf::VARDIR/filters",
-		"$NfConf::VARDIR/fmt",
-		"$NfConf::PROFILESTATDIR",
-		"$NfConf::PROFILESTATDIR/live",
-		"$NfConf::PROFILEDATADIR",
-		"$NfConf::PROFILEDATADIR/live",
+		"$NfConf::INSTPREFIX$NfConf::VARDIR",
+		"$NfConf::INSTPREFIX$NfConf::VARDIR/tmp",
+		"$NfConf::INSTPREFIX$NfConf::PIDDIR",
+		"$NfConf::INSTPREFIX$NfConf::FILTERDIR",
+		"$NfConf::INSTPREFIX$NfConf::FORMATDIR",
+		"$NfConf::INSTPREFIX$NfConf::PROFILESTATDIR",
+		"$NfConf::INSTPREFIX$NfConf::PROFILESTATDIR/live",
+		"$NfConf::INSTPREFIX$NfConf::PROFILEDATADIR",
+		"$NfConf::INSTPREFIX$NfConf::PROFILEDATADIR/live",
 	);
 
 	print "\nUse UID/GID $nfsen_uid $www_gid\n";
 
 	foreach my $dir ( @dirs ) {
-		$dir = $instdir.$dir;
 		if ( ! -d $dir ) {
 			print "Creating: ";
-			mkdir $dir || die "Can't mkdir '$dir': $!\n";
+			mkpath($dir, 1, 0755) || die "Can't mkpath '$dir': $!\n";
 		} else {
 			print "Exists: ";
 		}
@@ -394,10 +382,9 @@ sub SetupEnv {
 	print "\nProfile live: spool directories:\n";
 	foreach my $ident ( keys %NfConf::sources ) {
 		my $dir = "$NfConf::PROFILEDATADIR/live/$ident";
-		$dir = $instdir.$dir;
 		if ( ! -d $dir ) {
 			print "Creating: ";
-			mkdir $dir || die "Can't mkdir '$dir': $!\n";
+			mkpath($dir, 1, 0755) || die "Can't mkpath '$dir': $!\n";
 		} else {
 			print "Exists: ";
 		}
@@ -411,7 +398,7 @@ sub SetupEnv {
 	my $now = time();
 	my $tstart = $now - ( $now % 300 );
 	foreach my $db ( keys %NfConf::sources ) {
-		NfSenRRD::SetupRRD("$instdir$NfConf::PROFILESTATDIR/live", $db, $tstart - 300, 0);
+		NfSenRRD::SetupRRD("$NfConf::PROFILESTATDIR/live", $db, $tstart - 300, 0);
 	}
 	if ( $Log::ERROR ) {
 		die "Error setup RRD DBs: $Log::ERROR\n";
@@ -448,7 +435,7 @@ sub SetupEnv {
 		print "Use existing profile info for profile 'live'\n";
 	}
 
-	my $filelist = "$instdir$NfConf::PROFILESTATDIR/live/*rrd $instdir$NfConf::PROFILESTATDIR/live/profile.dat";
+	my $filelist = "$NfConf::PROFILESTATDIR/live/*rrd $NfConf::PROFILESTATDIR/live/profile.dat";
 	my @AllFIles = glob($filelist);
 	chown $nfsen_uid, $www_gid, @AllFIles;
 
@@ -485,8 +472,8 @@ sub UpgradeProfiles {
 
 	# fix permissions - all files/directories should ne $NfConf::USER and no longer WWW, as 
 	# no php script will no longer write anything
-	chown $nfsen_uid, $www_gid, "$instdir$NfConf::PROFILEDATADIR";
-	chown $nfsen_uid, $www_gid, "$instdir$NfConf::PROFILESTATDIR";
+	chown $nfsen_uid, $www_gid, "$NfConf::PROFILEDATADIR";
+	chown $nfsen_uid, $www_gid, "$NfConf::PROFILESTATDIR";
 
 	foreach my $profilename ( @AllProfiles ) {
 		my %profileinfo = NfProfile::ReadProfile($profilename, '.');
@@ -529,9 +516,9 @@ sub UpgradeProfiles {
 				# copy filter files
 
 				if ( $profileinfo{'type'} == 1 ) {
-					$oldfilter    = "$NfConf::PROFILEDATADIR/$profilename/history_filter.txt";
+					$oldfilter	= "$NfConf::PROFILEDATADIR/$profilename/history_filter.txt";
 				} else {
-					$oldfilter    = "$NfConf::PROFILEDATADIR/$profilename/filter.txt";
+					$oldfilter	= "$NfConf::PROFILEDATADIR/$profilename/filter.txt";
 				}
 				my $newfilter = "$NfConf::PROFILESTATDIR/$profilename/$channel-filter.txt";
 
@@ -591,19 +578,18 @@ sub CopyAllFiles {
 	$CopyRecursive::GID 	 = $www_gid;
 	$CopyRecursive::MODE 	 = 0755;
 	unlink "$NfConf::BINDIR/nfsen.rc";
-	CopyRecursive::dircopy("bin", "$instdir$NfConf::BINDIR");
-	CopyRecursive::dircopy("libexec", "$instdir$NfConf::LIBEXECDIR");
+	CopyRecursive::dircopy("bin", "$NfConf::INSTPREFIX$NfConf::BINDIR");
+	CopyRecursive::dircopy("libexec", "$NfConf::INSTPREFIX$NfConf::LIBEXECDIR");
 	$CopyRecursive::MODE 	 = 0644;
-	CopyRecursive::dircopy("etc", "$instdir$NfConf::CONFDIR");
-	CopyRecursive::dircopy("plugins/backend",  "$instdir$NfConf::BACKEND_PLUGINDIR");
-	CopyRecursive::dircopy("plugins/frontend", "$instdir$NfConf::FRONTEND_PLUGINDIR");
-	CopyRecursive::dircopy("doc", "$instdir$NfConf::DOCDIR");
+	CopyRecursive::dircopy("etc", "$NfConf::INSTPREFIX$NfConf::CONFDIR");
+	CopyRecursive::dircopy("plugins/backend",  "$NfConf::INSTPREFIX$NfConf::BACKEND_PLUGINDIR");
+	CopyRecursive::dircopy("plugins/frontend", "$NfConf::INSTPREFIX$NfConf::FRONTEND_PLUGINDIR");
 
-	if ( $ConfigFile eq "$instdir$NfConf::CONFDIR/nfsen.conf" ) { # XXX??
+	if ( $ConfigFile eq "$NfConf::INSTPREFIX$NfConf::CONFDIR/nfsen.conf" ) {
 		print "Keep config file '$ConfigFile'\n";
 	} else {
 		print "Copy config file '$ConfigFile'\n";
-		CopyRecursive::fcopy("$ConfigFile", "$instdir$NfConf::CONFDIR/nfsen.conf");
+		CopyRecursive::fcopy("$ConfigFile", "$NfConf::INSTPREFIX$NfConf::CONFDIR/nfsen.conf");
 	}
 	print "\n";
 
@@ -637,7 +623,7 @@ $| = 1;
 
 my $ConfigFile = shift @ARGV;
 my $mode = shift @ARGV;
-
+ 
 my $configure;
 my $copy;
 $configure=1 if $mode eq '';
@@ -687,9 +673,7 @@ if ( -f "$NfConf::CONFDIR/nfsen.conf" && -f "etc/nfsen.conf" &&
 
 Log::LogInit();
 
-my $hints;
-if ($configure) {
-$hints = NfSen::LoadHints();
+my $hints = NfSen::LoadHints();
 if ( $$$hints{'version'} == -1 ) {
 	# initial NfSen install or upgrade from old version without hints
 	$$$hints{'version'} 		= $nfsen_version;
@@ -698,7 +682,6 @@ if ( $$$hints{'version'} == -1 ) {
 	print "Upgrade from version '$$$hints{'version'}' installed at " . scalar localtime $$$hints{'installed'};
 	print "\n";
 }
-}
 
 
 my $rrd_version = $RRDs::VERSION;
@@ -709,14 +692,23 @@ if ( !defined $NfConf::RRDoffset ) {
 	die "$Log::ERROR\n";
 }
 
-
 # 
 print "Setup NfSen:\n";
 print "Version: $nfsen_version: $VERSION\n\n";
 
 # Get Perl
-# Put this into a NfCOnf Variablee, so we can use the standard Patch Procedure
-$NfConf::PERL = GetPerl();
+# Put this into a NfConf variable, so we can use the standard Patch Procedure
+#$NfConf::PERL = GetPerl();
+$NfConf::PERL = FindCommand("perl");
+$NfConf::INSTPREFIX = $ENV{'INSTPREFIX'};
+if ( defined $NfConf::INSTPREFIX ) {
+	if ( ! $NfConf::INSTPREFIX =~ /\/$/ ) {
+		$NfConf::INSTPREFIX = $NfConf::INSTPREFIX . '/';	# make sure path ends with a '/' 
+	}
+	print "Install prefixdir: '$NfConf::INSTPREFIX'\n";
+} else {
+	$NfConf::INSTPREFIX = '';
+}
 
 
 my ($nfsen_uid, $www_gid ) = VerifyConfig();
@@ -725,39 +717,43 @@ my $need_rrdlayout_upgrade = undef;
 my $rrdtool = undef;
 
 if ($configure) {
-	# test for two files of old layout
-	my $need_rrdlayout_upgrade = -f "$NfConf::PROFILESTATDIR/live/flows.rrd" && -f "$NfConf::PROFILESTATDIR/live/packets_other.rrd";
+# test for two files of old layout
+my $need_rrdlayout_upgrade = -f "$NfConf::PROFILESTATDIR/live/flows.rrd" && -f "$NfConf::PROFILESTATDIR/live/packets_other.rrd";
 
-	if ( $need_rrdlayout_upgrade ) {
-		$rrdtool = FindCommand("rrdtool");
-		if ( !defined $rrdtool ) {
-			print "\nERROR: command 'rrdtool' not found in your PATH: 'rrdtool' is needed to upgrade the DBs of your NfSen version\n";
-			exit 1;
-		}
+my $rrdtool = undef;
+if ( $need_rrdlayout_upgrade ) {
+	$rrdtool = FindCommand("rrdtool");
+	if ( !defined $rrdtool ) {
+		print "\nERROR: command 'rrdtool' not found in your PATH: 'rrdtool' is needed to upgrade the DBs of your NfSen version\n";
+		exit 1;
 	}
+}
 
-	my $pid_name = "nfsend.pid";
-	if ( -f "$NfConf::VARDIR/run/nfsen-run.pid" ) {
-		# from NfSen <= 1.2
-		$pid_name = "nfsen-run.pid";
-	}
+my $pid_name = "nfsend.pid";
 
-	if ( -f "$NfConf::VARDIR/run/$pid_name" ) {
-		open PID, "$NfConf::VARDIR/run/$pid_name" || die "Can't open pid file: $!\n";
+if ( -f "$NfConf::PIDDIR/$pid_name" ) {
+	my ($major, $minor, $release) = split /\./, $$$hints{'version'};
+	if ( $release < 5 ) {
+		# for older releases than 1.3.5 upgrade we to stop nfsen completely
+		print "Stop NfSen completely while upgrading to version $nfsen_version\n";
+		$nfsen_run = 2;	# a complete restart needed
+		system("$NfConf::BINDIR/nfsen stop");
+	} else {
+		open PID, "$NfConf::PIDDIR/$pid_name" || die "Can't open pid file: $!\n";
 		my $pid = <PID>;
 		chomp($pid);
 		close PID;
-		die "Can't extract PID out of '$NfConf::VARDIR/run/$pid_name'. Stop upgrade" if !defined $pid;
+		die "Can't extract PID out of '$NfConf::PIDDIR/$pid_name'. Stop upgrade" if !defined $pid;
 		if ( kill(0, $pid) == 1 ) {
 			print "Stop nfsend while upgrading .";
 			kill 15, $pid;
 			my $cnt = 0;
-			while ( -f "$NfConf::VARDIR/run/$pid_name" && $cnt < 300 ) {
+			while ( -f "$NfConf::PIDDIR/$pid_name" && $cnt < 300 ) {
 				print ".";
 				$cnt++;
 				sleep(1);
 			}
-			if ( -f "$NfConf::VARDIR/run/$pid_name" ) {
+			if ( -f "$NfConf::PIDDIR/$pid_name" ) {
 				print "\nnfsend doesn't want to die! It's not save to upgrade NfSen!\n";
 				exit;
 			} else {
@@ -766,18 +762,18 @@ if ($configure) {
 			}
 		} else {
 			print "nfsend pid file exists, but no process is running.\n";
-			unlink "$NfConf::VARDIR/run/$pid_name";
+			unlink "$NfConf::PIDDIR/$pid_name";
 		}
 	}
 }
-
-if ($copy) {
-	SetupHTML($nfsen_uid, $www_gid);
-	CopyAllFiles($ConfigFile, $nfsen_uid, $www_gid);
-	PatchAllScripts();
 }
 
-if ($configure) { # Not indented; cvs keywords in following block will break ports tree patches
+if ($copy) {
+SetupHTML($nfsen_uid, $www_gid);
+CopyAllFiles($ConfigFile, $nfsen_uid, $www_gid);
+PatchAllScripts();
+}
+if ($configure) {
 Cleanup();
 SetupEnv($nfsen_uid, $www_gid);
 
@@ -800,23 +796,39 @@ if ( $need_rrdlayout_upgrade ) {
 	}
 }
 
+if ( !exists $$$hints{'sources'} ) {
+	foreach my $source ( sort keys %NfConf::sources ) {
+		my $port = $NfConf::sources{$source}{'port'};
+		$$$hints{'sources'}{$source} = $port;
+	}
+}
 
 Nfsources::Reconfig();
+delete $$$hints{'sources'};
+foreach my $source ( sort keys %NfConf::sources ) {
+	$$$hints{'sources'}{$source} = $NfConf::sources{$source}{'port'};
+}
+
 
 $$$hints{'version'} 		= $nfsen_version;
 $$$hints{'installed'} 		= time();
 NfSen::StoreHints();
-chown $nfsen_uid, $www_gid, "$NfConf::PROFILESTATDIR/hints" || die "Can't chown hints db: $!\n";
+chown $nfsen_uid, $www_gid, "$NfConf::INSTPREFIX$NfConf::PROFILESTATDIR/hints" || die "Can't chown hints db: $!\n";
 }
 print "Setup done.\n\n";
 
-if ( $copy && $nfsen_run ) {
+if ( $configure ) {
+if ( $nfsen_run == 2 ) {
+	print "Restart NfSen\n";
+	system("$NfConf::BINDIR/nfsen start");
+} elsif ( $nfsen_run == 1 ) {
 	print "Restart nfsend\n";
 	system("$NfConf::BINDIR/nfsend");
-}
+} 
+} 
 
 print "* You may want to subscribe to the nfsen-discuss mailing list:\n";
 print "* http://lists.sourceforge.net/lists/listinfo/nfsen-discuss\n";
-print "* Please send bug reports back to me: peter.haag\@switch.ch\n";
+print "* Please send bug reports back to me: phaag\@sourceforge.net\n";
 exit 0;
 
