@@ -26,11 +26,11 @@
 #  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 #  POSSIBILITY OF SUCH DAMAGE.
 #
-#  $Author: phaag $
+#  $Author: haag $
 #
-#  $Id: NfAlert.pm 8 2007-07-17 12:19:44Z phaag $
+#  $Id: NfAlert.pm 67 2010-09-09 05:56:05Z haag $
 #
-#  $LastChangedRevision: 8 $
+#  $LastChangedRevision: 67 $
 
 package NfAlert;
 
@@ -2088,4 +2088,18 @@ sub GetAlertGraph {
 
 } # End of GetAlertGraph
 
+sub CleanAlerts {
+	foreach my $alertname ( AlertList() ) {
+		opendir(PROFILEDIR, "$NfConf::PROFILEDATADIR/~$alertname/$alertname/" ) or
+		syslog('err', "Can't open alert data directory: '$NfConf::PROFILEDATADIR/~$alertname/$alertname/': $!");
+		my @OldFlowFiles = grep { $_ =~ /nfcapd/ || $_ =~ /nfprofile/ } 
+							readdir(PROFILEDIR);
+		closedir PROFILEDIR;
+		
+		foreach my $filename (@OldFlowFiles) { 
+			unlink "$NfConf::PROFILEDATADIR/~$alertname/$alertname/$filename";
+		}
+
+	}
+} # End of CleanAlerts
 1;
