@@ -26,11 +26,11 @@
 #  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 #  POSSIBILITY OF SUCH DAMAGE.
 #
-#  $Author: phaag $
+#  $Author: haag $
 #
-#  $Id: NfProfile.pm 22 2007-11-20 12:27:38Z phaag $
+#  $Id: NfProfile.pm 67 2010-09-09 05:56:05Z haag $
 #
-#  $LastChangedRevision: 22 $
+#  $LastChangedRevision: 67 $
 
 package NfProfile;
 
@@ -290,7 +290,8 @@ sub ProfileList {
 		$Log::ERROR = "Can't open profile group directory: $!", 
 		return @AllProfiles;
 
-	@AllProfiles = grep {  -f "$NfConf::PROFILESTATDIR/$profilegroup/$_/profile.dat" && $_ !~ /^\./ && $_ ne 'live' } 
+	@AllProfiles = grep {  -f "$NfConf::PROFILESTATDIR/$profilegroup/$_/profile.dat" && $_ !~ /^\./ && $_ ne 'live' && 
+						  !-f "$NfConf::PROFILESTATDIR/$profilegroup/$_/.DELETED" } 
 						readdir(PROFILEDIR);
 
 	closedir PROFILEDIR;
@@ -304,6 +305,48 @@ sub ProfileList {
 
 } # End of ProfileList
 
+sub DeleteDelayed {
+
+	foreach my $profilegroup ( ProfileGroups() ) {
+		my @AllProfiles;
+		opendir(PROFILEDIR, "$NfConf::PROFILESTATDIR/$profilegroup" ) or
+			$Log::ERROR = "Can't open profile group directory: $!", 
+			return @AllProfiles;
+	
+		@AllProfiles = grep {  -f "$NfConf::PROFILESTATDIR/$profilegroup/$_/.DELETED" } 
+							readdir(PROFILEDIR);
+	
+		closedir PROFILEDIR;
+
+		# delete each profile
+		foreach my $profile ( @AllProfiles ) {
+			my $profilepath = ProfilePath($profile, $profilegroup);
+			syslog('err', "Delete delayed: profile '$profile' in group '$profilegroup' ");
+
+			my @dirs;
+			push @dirs, "$NfConf::PROFILESTATDIR";
+			if ( "$NfConf::PROFILESTATDIR" ne "$NfConf::PROFILEDATADIR" ) {
+				push @dirs, "$NfConf::PROFILEDATADIR";
+			}
+
+			foreach my $dir ( @dirs ) {
+				if ( !rename "$dir/$profilepath", "$dir/.$profile" ) {
+					syslog('err', "Failed to rename profile '$profile' in group '$profilegroup' in order to delete: $!");
+					next;
+				} 
+
+				my $command = "/bin/rm -rf $dir/.$profile &";
+				system($command);
+				if ( defined $main::child_exit && $main::child_exit != 0 ) {
+					syslog('err', "Failed to execute command: $!\n");
+					syslog('err', "system command was: '$command'\n");
+				} 
+			}
+		}
+	}
+
+} # End of ProfileList
+
 
 #
 # Return an array of names of all channels in this profile
@@ -887,6 +930,10 @@ sub ProfileHistory {
 	my $profile_size = 0;
 	my $t = $tstart; 
 	while ( $t <= $tend ) {
+		if ( -f "$NfConf::PROFILESTATDIR/$profilepath/.CANCELED" ) {
+			last;
+		}
+
 		my $iso = NfSen::UNIX2ISO($t);
 		my $subdirs = NfSen::SubdirHierarchy($t);
 		my %statinfo	= ();
@@ -900,7 +947,9 @@ sub ProfileHistory {
 			$completed = 100;
 		}
 		if ( ($counter % $modulo ) == 0 ) {
-			$$profileref{'status'} = "built $completed\n";
+			$$profileref{'status'} 	= "built $completed\n";
+			$$profileref{'updated'} = $t;
+			$$profileref{'size'} 	= $profile_size;
 			WriteProfile($profileref);
 			syslog('info', "Build Profile '$name':	 Completed: $completed\%"),
 		}
@@ -927,16 +976,43 @@ sub ProfileHistory {
 				my $outfile = "$NfConf::PROFILEDATADIR/$profilepath/$channel/$subdirs/nfcapd.$iso";
 	
 				# array element 7 contains the size in bytes
-				$profile_size += (stat($outfile))[7];
+				$profile_size +=(stat($outfile))[7];
 			}
 		}
 		$t += 300;
 		if ( $continous_profile && $t == $tend ) {
 			my %liveprofile = ReadProfile('live', '.');
 			$tend = $liveprofile{'tend'};
+			$$profileref{'tend'} = $tend;
+		}
+		if ( $$profileref{'maxsize'} && ( $profile_size > $$profileref{'maxsize'} )) {
+			syslog('err', "Reached profile max size while building. Cancel building");
+			open CANCELFLAG, ">$NfConf::PROFILESTATDIR/$profilepath/.CANCELED";
+			close CANCELFLAG;
+		}
+		if ( $$profileref{'expire'} && ( $t - $tstart ) > $$profileref{'expire'}*3600 ) {
+			syslog('err', "Reached profile max lifetime while building. Cancel building");
+			open CANCELFLAG, ">$NfConf::PROFILESTATDIR/$profilepath/.CANCELED";
+			close CANCELFLAG;
 		}
 	}
-	syslog('info', "ProfileHistory: Done."),
+	if ( -f "$NfConf::PROFILESTATDIR/$profilepath/.CANCELED" ) {
+		syslog('info', "ProfileHistory: canceled."),
+		# Canceled profiles become a history profile
+		$$profileref{'tend'}    = $t;
+		if ( ($$profileref{'type'} & 4) > 0 ) { # is shadow
+			$$profileref{'type'}  = 1;
+			$$profileref{'type'} += 4;
+		} else {
+			$$profileref{'type'} = 1;
+		}
+		unlink "$NfConf::PROFILESTATDIR/$profilepath/.CANCELED";
+	} else {
+		syslog('info', "ProfileHistory: Done."),
+	}
+
+	$$profileref{'size'} 	= $profile_size;
+	$$profileref{'updated'} = $t;
 
 	return $profile_size;
 
@@ -1763,6 +1839,14 @@ sub AddProfileChannel {
 	}
 
 	my $colour = '#abcdef';
+	my $sign   = '+';
+	my $order  = 0;
+	if ( exists $liveprofile{'channel'}{$channel} ) {
+		$colour = $liveprofile{'channel'}{$channel}{'colour'};
+		$sign   = $liveprofile{'channel'}{$channel}{'sign'};
+	 	$order  = $liveprofile{'channel'}{$channel}{'order'};
+	} 
+
 	if ( exists $$opts{'colour'} ) {
 		if ( $$opts{'colour'} !~ /^#[0-9a-f]{6}$/i ) {
 			print $socket $EODATA;
@@ -1770,12 +1854,8 @@ sub AddProfileChannel {
 			return;
 		} 
 		$colour = $$opts{'colour'};
-	} elsif ( exists $NfConf::sources{$channel}{'col'} ) {
-        $colour = $NfConf::sources{$channel}{'col'};
-    }
+	} 
 
-
-	my $sign = '+';
 	if ( exists $$opts{'sign'} ) {
 		if ( $$opts{'sign'} !~ /^[+\-]$/ ) {
 			print $socket $EODATA;
@@ -1785,7 +1865,6 @@ sub AddProfileChannel {
 		$sign = $$opts{'sign'};
 	}
 
-	my $order = 0;
 	if ( exists $$opts{'order'} ) {
 		if ( $$opts{'order'} !~ /^[0-9]+$/ ) {
 			print $socket $EODATA;
@@ -1912,6 +1991,49 @@ sub DeleteProfileChannel {
 
 } # End of DeleteProfileChannel
 
+sub CancelProfile {
+	my $socket	= shift;
+	my $opts 	= shift;
+
+	my ($profile, $profilegroup);
+	my $ret = ProfileDecode($opts, \$profile, \$profilegroup);
+	if ( $ret ne 'ok' ) {
+		print $socket $EODATA;
+		print $socket "ERR $ret\n";
+		return;
+	} 
+
+	$ret = VerifyProfile($profile, $profilegroup, 1);
+	if ( $ret ne 'ok' ) {
+		print $socket $EODATA;
+		print $socket "ERR $ret\n";
+		return;
+	} 
+	
+	my $profilepath = ProfilePath($profile, $profilegroup);
+
+	if ( $profile eq 'live' && $profilegroup eq '.') {
+		print $socket $EODATA;
+		print $socket "ERR Don't want to delete profile 'live'!\n";
+		return;
+	}
+
+	my %profileinfo = ReadProfile($profile, $profilegroup);
+	if ( ! -f "$NfConf::PROFILESTATDIR/$profilepath/.BUILDING" ) {
+		print $socket $EODATA;
+		print $socket "ERR No such build in progress\n";
+		return;
+	}
+
+	open CANCELFLAG, ">$NfConf::PROFILESTATDIR/$profilepath/.CANCELED";
+	close CANCELFLAG;
+
+	print $socket $EODATA;
+	print $socket "OK Building profile '$profile' canceled.\n";
+
+} # End of CancelProfile
+
+
 sub DeleteProfile {
 	my $socket	= shift;
 	my $opts 	= shift;
@@ -1951,11 +2073,14 @@ sub DeleteProfile {
 		print $socket "ERR Profile '$profile' is locked and can not be deleted now!\n";
 		return;
 	}
-	if ( ! exists $$opts{'force'} && $profileinfo{'status'} ne 'OK' ) {
+	if ( ! exists $$opts{'force'} && ( $profileinfo{'status'} ne 'OK' && $profileinfo{'status'} ne 'DELETED' )) {
 		print $socket $EODATA;
 		print $socket "ERR Profile '$profile' is not in status 'OK' and can not be deleted now!\n";
 		return;
 	}
+	%profileinfo = LockProfile($profile, $profilegroup);
+	$profileinfo{'status'} = 'DELETED';
+	WriteProfile(\%profileinfo);
 
 	my @dirs;
 	push @dirs, "$NfConf::PROFILESTATDIR";
@@ -1964,8 +2089,11 @@ sub DeleteProfile {
 	}
 	foreach my $dir ( @dirs ) {
 		if ( !main::semnowait($main::semlock) ) {
+			open DELFLAG, ">$NfConf::PROFILESTATDIR/$profilepath/.DELETED";
+			print DELFLAG "profile deleted and to be removed later\n";
+			close DELFLAG;
 			print $socket $EODATA;
-			print $socket "ERR Can not delete the profile while a periodic update is in progress. Try again later.\n";
+			print $socket "OK Profile '$profile' deleted.\n";
 			return;
 		}
 
@@ -2084,6 +2212,7 @@ sub CommitProfile {
 		return;
 	} 
 	
+	my $profilepath	= ProfilePath($profile, $profilegroup);
 	# is this a new profile
 	my %profileinfo = ReadProfile($profile, $profilegroup);
 	if ( $profileinfo{'status'} ne 'new' && $profileinfo{'status'} ne 'stalled' ) {
@@ -2127,10 +2256,11 @@ sub CommitProfile {
 		}
 		if ( $pid ) { 
 			# we are the parent processs
+			print $socket "pid=$pid\n";
 			print $socket $EODATA;
 			print $socket "OK Profiling netflow data\n";
-			open PID, ">$NfConf::PIDDIR/build.${pid}" || 
-				warn "Can't open pid file: $!";
+			open PID, ">$NfConf::PROFILESTATDIR/$profilepath/.BUILDING" || 
+				syslog('err', "Can't open pid file: $NfConf::PROFILESTATDIR/$profilepath/.BUILDING: $!");
 			print PID "$pid\n";
 			close PID;
 			return;
@@ -2149,10 +2279,9 @@ sub CommitProfile {
 		open STDOUT, '>/dev/null' || die "Can't write to /dev/null: $!";
 		open STDERR, '>/dev/null' || die "Can't write to /dev/null: $!";
 
-		$profileinfo{'size'} 	= ProfileHistory(\%profileinfo);
+		ProfileHistory(\%profileinfo);
 
-		$profileinfo{'updated'}	= $profileinfo{'tend'};
-		unlink "$NfConf::PIDDIR/build.$$";
+		unlink "$NfConf::PROFILESTATDIR/$profilepath/.BUILDING";
 
 		syslog('debug', "Graph update profile: $profile, Time: $profileinfo{'tend'}.");
 		if ( NfSenRRD::UpdateGraphs($profile, $profilegroup, $profileinfo{'tend'}, 1) ) {
@@ -3106,6 +3235,84 @@ sub CompileFileArg {
 	
 } # End of CompileFileArg
 
+sub CancelBuilds {
+
+	foreach my $profilegroup ( ProfileGroups() ) {
+		my @AllProfiles;
+		opendir(PROFILEDIR, "$NfConf::PROFILESTATDIR/$profilegroup" ) or
+			$Log::ERROR = "Can't open profile group directory: $!", 
+			return @AllProfiles;
+	
+		@AllProfiles = grep {  -f "$NfConf::PROFILESTATDIR/$profilegroup/$_/.BUILDING" } 
+							readdir(PROFILEDIR);
+	
+		closedir PROFILEDIR;
+
+		# delete each profile
+		foreach my $profile ( @AllProfiles ) {
+			my $profilepath = ProfilePath($profile, $profilegroup);
+			syslog('err', "Cancel building profile '$profile' in group '$profilegroup' ");
+			open CANCELFLAG, ">$NfConf::PROFILESTATDIR/$profilepath/.CANCELED";
+			close CANCELFLAG;
+			my $i = 0;
+			while ( ($i < 60) && -f "$NfConf::PROFILESTATDIR/$profilepath/.CANCELED" ) {
+				sleep(1);
+				$i++;
+			}
+			if ( -f "$NfConf::PROFILESTATDIR/$profilepath/.CANCELED" ) { 
+				syslog('err', "Cancel building profile '$profile' in group '$profilegroup' did not succeed! Abort waiting!");
+			}
+		}
+	}
+
+} # End of CancelBuilds
+
+sub CheckProfiles {
+
+	foreach my $profilegroup ( ProfileGroups() ) {
+		my @AllProfiles = ProfileList($profilegroup);
+		foreach my $profile ( @AllProfiles ) {
+			my $profilepath = ProfilePath($profile, $profilegroup);
+			my %profileinfo = ReadProfile($profile, $profilegroup);
+			if ( -f "$NfConf::PROFILESTATDIR/$profilepath/.BUILDING" ) {
+				syslog('err', "Clean-up debris profile '$profile' in group '$profilegroup' ");
+				unlink "$NfConf::PROFILESTATDIR/$profilepath/.BUILDING";
+				$profileinfo{'tend'} = $profileinfo{'updated'};
+				if ( ($profileinfo{'type'} & 4) > 0 ) { # is shadow
+					$profileinfo{'type'}  = 1;
+					$profileinfo{'type'} += 4;
+				} else {
+					$profileinfo{'type'} = 1;
+				}
+				my $status = DoRebuild(\%profileinfo, $profile, $profilegroup, $profilepath, 0);
+				syslog('err', "Rebuilded profile '$profile' in group '$profilegroup': $status ");
+			}
+			if ( -f "$NfConf::PROFILESTATDIR/$profilepath/.CANCELED" ) {
+				syslog('err', "Clean-up debris profile '$profile' in group '$profilegroup' ");
+				unlink "$NfConf::PROFILESTATDIR/$profilepath/.CANCELED";
+				if ( ($profileinfo{'type'} & 4) > 0 ) { # is shadow
+					$profileinfo{'type'}  = 1;
+					$profileinfo{'type'} += 4;
+				} else {
+					$profileinfo{'type'} = 1;
+				}
+				my $status = DoRebuild(\%profileinfo, $profile, $profilegroup, $profilepath, 0);
+				syslog('err', "Rebuilded profile '$profile' in group '$profilegroup': $status ");
+			}
+			if ( $profileinfo{'locked'} ) {
+				syslog('err', "Clean-up debris profile '$profile' in group '$profilegroup' ");
+				$profileinfo{'locked'} = 0;
+			} 
+			if ( !WriteProfile(\%profileinfo) ) {
+				syslog('err', "Error writing profile '$profile' in group '$profilegroup' ");
+			}
+		}
+	}
+
+
+
+} # End of CheckProfiles
+
 1;
 
 
