@@ -27,11 +27,11 @@
 #  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 #  POSSIBILITY OF SUCH DAMAGE.
 #
-#  $Author: phaag $
+#  $Author: haag $
 #
-#  $Id: NfSen.pm 12 2007-07-19 10:54:58Z phaag $
+#  $Id: NfSen.pm 67 2010-09-09 05:56:05Z haag $
 #
-#  $LastChangedRevision: 12 $
+#  $LastChangedRevision: 67 $
 
 package NfSen;
 
@@ -450,12 +450,12 @@ sub GetDefaultFilterList {
 	my $socket  = shift;
 	my $opts	= shift;
 
-    opendir(FILTERS, "$NfConf::VARDIR/filters/" ) or
+    opendir(FILTERS, "$NfConf::FILTERDIR" ) or
 		print $socket $EODATA,
-        print "ERR Can't open filter directory: $!", 
+        print "ERR Can't open filter directory '$NfConf::FILTERDIR': $!", 
         return;
 
-    my @AllFilters = grep { $_ !~ /^\.+/ && -f "$NfConf::VARDIR/filters/$_" } readdir(FILTERS);
+    my @AllFilters = grep { $_ !~ /^\.+/ && -f "$NfConf::FILTERDIR/$_" } readdir(FILTERS);
 
     closedir FILTERS;
 
@@ -485,13 +485,13 @@ sub GetDefaultFilter {
 		return;
 	}
 
-	if ( !-f "$NfConf::VARDIR/filters/$name" ) {
+	if ( !-f "$NfConf::FILTERDIR/$name" ) {
 		print $socket $EODATA;
 		print $socket "ERR filter '$name' No such filter!\n";
 		return;
 	}
 
-	if ( open FILTER, "$NfConf::VARDIR/filters/$name" ) {
+	if ( open FILTER, "$NfConf::FILTERDIR/$name" ) {
 		while ( <FILTER> ) {
 			chomp;
 			print $socket "_filter=$_\n";
@@ -524,7 +524,7 @@ sub AddDefaultFilter {
 		return;
 	}
 
-	if ( -f "$NfConf::VARDIR/filters/$name" && !exists $$opts{'overwrite'} ) {
+	if ( -f "$NfConf::FILTERDIR/$name" && !exists $$opts{'overwrite'} ) {
 		print $socket $EODATA;
 		print $socket "ERR filter '$name' already exists!\n";
 		return;
@@ -546,8 +546,8 @@ sub AddDefaultFilter {
 	}
 
 	# clean old file
-	unlink "$NfConf::VARDIR/filters/$name";
-	if ( !open FILTER, ">$NfConf::VARDIR/filters/$name" ) {
+	unlink "$NfConf::FILTERDIR/$name";
+	if ( !open FILTER, ">$NfConf::FILTERDIR/$name" ) {
 		print $socket $EODATA;
 		print $socket "ERR Failed to open filter file '$name': $!!\n";
 		return;
@@ -576,13 +576,13 @@ sub DeleteDefaultFilter {
 		return;
 	}
 
-	if ( ! -f "$NfConf::VARDIR/filters/$name" ) {
+	if ( ! -f "$NfConf::FILTERDIR/$name" ) {
 		print $socket $EODATA;
 		print $socket "ERR No such filter '$name'!\n";
 		return;
 	}
 
-	if ( !unlink "$NfConf::VARDIR/filters/$name" ) {
+	if ( !unlink "$NfConf::FILTERDIR/$name" ) {
 		print $socket $EODATA;
 		print $socket "ERR Can not delete filter '$name': $!!\n";
 		return;
@@ -598,17 +598,17 @@ sub GetOutputFormats {
 	my $socket  = shift;
 	my $opts	= shift;
 
-    opendir(FORMATS, "$NfConf::VARDIR/fmt/" ) or
+    opendir(FORMATS, "$NfConf::FORMATDIR" ) or
 		print $socket $EODATA,
-        print "ERR Can't open format directory: $!", 
+        print "ERR Can't open format directory '$NfConf::FORMATDIR' : $!", 
         return;
 
-    my @AllFormats = grep { $_ !~ /^\.+/ && -f "$NfConf::VARDIR/fmt/$_" } readdir(FORMATS);
+    my @AllFormats = grep { $_ !~ /^\.+/ && -f "$NfConf::FORMATDIR/$_" } readdir(FORMATS);
 
     closedir FORMATS;
 
 	foreach my $format ( @AllFormats ) {
-		if ( open FMT, "$NfConf::VARDIR/fmt/$format" ) {
+		if ( open FMT, "$NfConf::FORMATDIR/$format" ) {
 			my $formatdef = <FMT>;
 			close FMT;
 			chomp $formatdef;
@@ -658,15 +658,15 @@ sub AddOuputFormat {
 		return;
 	}
 
-	if ( -f "$NfConf::VARDIR/fmt/$format" && !exists $$opts{'overwrite'} ) {
+	if ( -f "$NfConf::FORMATDIR/$format" && !exists $$opts{'overwrite'} ) {
 		print $socket $EODATA;
 		print $socket "ERR format '$format' already exists!\n";
 		return;
 	}
 
 	# clean old file
-	unlink "$NfConf::VARDIR/fmt/$format";
-	if ( !open FMT, ">$NfConf::VARDIR/fmt/$format" ) {
+	unlink "$NfConf::FORMATDIR/$format";
+	if ( !open FMT, ">$NfConf::FORMATDIR/$format" ) {
 		print $socket $EODATA;
 		print $socket "ERR Failed to open format file '$format': $!!\n";
 		return;
@@ -696,13 +696,13 @@ sub DeleteOuputFormat {
 		return;
 	}
 
-	if ( ! -f "$NfConf::VARDIR/fmt/$format" ) {
+	if ( ! -f "$NfConf::FORMATDIR/$format" ) {
 		print $socket $EODATA;
 		print $socket "ERR No such format '$format'!\n";
 		return;
 	}
 
-	if ( !unlink "$NfConf::VARDIR/fmt/$format" ) {
+	if ( !unlink "$NfConf::FORMATDIR/$format" ) {
 		print $socket $EODATA;
 		print $socket "ERR Can not delete format '$format': $!!\n";
 		return;
