@@ -27,14 +27,15 @@
 #  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 #  POSSIBILITY OF SUCH DAMAGE.
 #
-#  $Author: phaag $
+#  $Author: haag $
 #
-#  $Id: Nfcomm.pm 21 2007-08-24 16:56:25Z phaag $
+#  $Id: Nfcomm.pm 67 2010-09-09 05:56:05Z haag $
 #
-#  $LastChangedRevision: 21 $
+#  $LastChangedRevision: 67 $
 package Nfcomm;
 
 use strict;
+no warnings 'deprecated';
 
 # BEGIN { $ENV{PATH} = '/usr/ucb:/bin' }
 
@@ -94,6 +95,7 @@ my %CMD_lookup = (
 	'delete-alert'			=> 	\&NfAlert::DeleteAlert,
 
 	'commit-profile'	=> 	\&NfProfile::CommitProfile,
+	'cancel-profile'	=> 	\&NfProfile::CancelProfile,
 	'modify-profile'	=> 	\&NfProfile::ModifyProfile,
 	'modify-channel'	=> 	\&NfProfile::ModifyProfileChannel,
 	'modify-alert'		=> 	\&NfAlert::ModifyAlert,
@@ -105,6 +107,7 @@ my %CMD_lookup = (
 
 	'lookup'			=>	 \&Lookup::Lookup,
 	'semcheck'   		=>   \&SemCheck,
+	'signal'   			=>   \&OpSignal,
 );
 
 
@@ -129,6 +132,9 @@ my $nfsen_version = 'unknown';
 my %ProfilePlugins;
 my %modules_loaded;
 
+our $in_periodic 	= 0;
+my $cleanup_trigger = 0;
+
 sub SIG_CHILD {
 	my $child;
 	$sigchld = 1;
@@ -193,6 +199,35 @@ sub SemCheck {
 	}
 } 
 
+sub OpSignal {
+	my $socket  = shift;
+	my $opts	= shift;
+
+	if ( !exists $$opts{'flag'} ) {
+		print $socket $EODATA;
+		print $socket "ERR Missing signal flag";
+		return;
+	} 
+
+	my $flag = $$opts{'flag'};
+
+	if ( $flag eq "start-periodic" ) {
+		$in_periodic = 1;
+	} elsif ( $flag eq "end-periodic" ) {
+		$in_periodic = 0;
+		$cleanup_trigger = 1;
+	} else {
+		print $socket $EODATA;
+		print $socket "ERR Illegal flag '$flag'!\n";
+		return;
+
+	}
+
+	print $socket $EODATA;
+	print $socket "OK signal\n";
+
+} # End of OpSignal
+
 sub RunNfdump {
 	my $socket 	= shift;
 	my $opts 	= shift;
@@ -243,14 +278,14 @@ sub RunNfdump {
 			return;
 		}
 
-		if ( !-f "$NfConf::VARDIR/filters/$name" ) {
+		if ( !-f "$NfConf::FILTERDIR/$name" ) {
 			print $socket $EODATA;
 			print $socket "ERR filter '$name' No such filter!\n";
 			return;
 		}
 
 		my @_tmp;
-		if ( open FILTER, "$NfConf::VARDIR/filters/$name" ) {
+		if ( open FILTER, "$NfConf::FILTERDIR/$name" ) {
 			@_tmp = <FILTER>;
 			close FILTER;
 		} else {
@@ -1148,6 +1183,11 @@ sub RunServer {
 						$quit = CmdDecode(\@input, $silent);
 					}
 				}
+			}	
+			if ( $cleanup_trigger ) {
+				$cleanup_trigger = 0;
+				syslog('debug', "Cleanup Routine");
+				NfProfile::DeleteDelayed();
 			}
 			return 0;
 		} # End of anonymous sub
